import * as i0 from '@angular/core';
import { Injectable, NgModule, InjectionToken, EventEmitter, Component, Renderer2, ViewChild, Input, Output, forwardRef, ChangeDetectorRef, SkipSelf, HostListener, ElementRef } from '@angular/core';
import * as dayjs from 'dayjs';
import { CommonModule } from '@angular/common';
import { __awaiter } from 'tslib';
import { ControlContainer, FormControlDirective, NG_VALUE_ACCESSOR, ReactiveFormsModule, SelectControlValueAccessor, CheckboxControlValueAccessor } from '@angular/forms';
import { MASKS, INPUT_TYPE, NgMaskService, NgMaskCurrencyService, NgMaskPercentService, NgMaskAmountService, NgMasksServicesModule } from '@douglas-serena/ng-masks';
import { getNode, contains, handleTry, NgFileDirectivesModule } from '@douglas-serena/ng-utils';
import { Overlay, OverlayModule } from '@angular/cdk/overlay';

class NgConfigService {
    constructor() {
        this._config = {
            global: {
                upload: {
                    icon: 'fas fa-upload',
                    label: 'ou arraste um arquivo até aqui',
                },
                select: {},
                textArea: {},
                autocomplete: {
                    icon: {
                        loading: {
                            icon: 'fas fa-spinner ng-bt-loading',
                        },
                        left: {
                            icon: 'fas fa-search',
                        },
                    },
                },
                input: {
                    types: {
                        password: {
                            icon: {
                                right: {
                                    icon: 'fas fa-eye',
                                    click: (_, input, icon) => {
                                        if (input.type === 'password') {
                                            icon.icon = 'fas fa-eye-slash';
                                            input.type = 'text';
                                        }
                                        else {
                                            icon.icon = 'fas fa-eye';
                                            input.type = 'password';
                                        }
                                    },
                                },
                            },
                        },
                    },
                },
            },
        };
    }
    get global() {
        return this.config.global;
    }
    get upload() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.upload;
    }
    get input() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.input;
    }
    get select() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.select;
    }
    get textarea() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.textArea;
    }
    get autocomplete() {
        var _a;
        return (_a = this.global) === null || _a === void 0 ? void 0 : _a.autocomplete;
    }
    get config() {
        return this._config;
    }
    set config(value) {
        this._config.global = Object.assign(Object.assign({}, this._config.global), value.global);
    }
    types(field) {
        var _a, _b;
        return (_b = (_a = this.global) === null || _a === void 0 ? void 0 : _a[field]) === null || _b === void 0 ? void 0 : _b.types;
    }
    get typesSelect() {
        return this.types('select');
    }
    get typesInput() {
        return this.types('input');
    }
    get typesTextArea() {
        return this.types('textArea');
    }
    get typesAutocomplete() {
        return this.types('autocomplete');
    }
}
NgConfigService.ɵprov = i0.ɵɵdefineInjectable({ factory: function NgConfigService_Factory() { return new NgConfigService(); }, token: NgConfigService, providedIn: "root" });
NgConfigService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];

class NgConfigModule {
    static forRoot() {
        return {
            ngModule: NgConfigModule,
            providers: [NgConfigService],
        };
    }
}
NgConfigModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                exports: [],
                providers: [NgConfigService],
            },] }
];

class NgInputsBootstrap {
    static forRoot(options) {
        return {
            ngModule: NgInputsBootstrap,
            providers: [
                NgConfigService,
                {
                    provide: FOR_ROOT_OPTIONS_TOKEN,
                    useValue: options,
                },
                {
                    provide: NgConfigService,
                    useFactory: provideMyServiceOptions,
                    deps: [FOR_ROOT_OPTIONS_TOKEN],
                },
            ],
        };
    }
}
NgInputsBootstrap.decorators = [
    { type: NgModule, args: [{
                imports: [NgConfigModule],
            },] }
];
var FOR_ROOT_OPTIONS_TOKEN = new InjectionToken('forRoot() NgConfigService() configuration.');
function provideMyServiceOptions(configs) {
    const service = new NgConfigService();
    if (configs) {
        service.config = configs;
    }
    return service;
}

class NgFormatDateByTypeService {
    constructor() {
        this.typeDate = ['date', 'datetime-local', 'month', 'time'];
    }
    format(value, typeDate) {
        const formulation = {
            'datetime-local': dayjs(value).format('YYYY-MM-DDTHH:mm:ss'),
            date: dayjs(value).format('YYYY-MM-DD'),
            month: dayjs(value).format('YYYY-MM'),
            time: dayjs(value).format('HH:mm'),
        };
        return formulation[typeDate];
    }
}
NgFormatDateByTypeService.ɵprov = i0.ɵɵdefineInjectable({ factory: function NgFormatDateByTypeService_Factory() { return new NgFormatDateByTypeService(); }, token: NgFormatDateByTypeService, providedIn: "root" });
NgFormatDateByTypeService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
NgFormatDateByTypeService.ctorParameters = () => [];

class NgUtilsServiceModule {
    static forRoot() {
        return {
            ngModule: NgUtilsServiceModule,
            providers: [NgFormatDateByTypeService],
        };
    }
}
NgUtilsServiceModule.decorators = [
    { type: NgModule, args: [{
                providers: [NgFormatDateByTypeService],
            },] }
];

class ControlBase {
    constructor(_controlContainer, _renderer2, _ngConfig) {
        this._controlContainer = _controlContainer;
        this._renderer2 = _renderer2;
        this._ngConfig = _ngConfig;
        this.label = '';
        this.type = 'text';
        this.readonly = false;
        this.disabled = false;
        this.required = null;
        this.labelFixed = false;
        this.color = 'primary';
        this.size = 'md';
        this.theme = 'outline';
        this.blur = new EventEmitter();
        this.focus = new EventEmitter();
        this.handleChange = (_) => { };
        this.handleTouched = () => { };
        this.registerOnTouched = (fn) => (this.handleTouched = fn);
        this.setDisabledState = (isDisabled) => (this.disabled = isDisabled);
        this.registerOnChange = (fn) => (this.handleChange = fn);
        this.writeValue = (value) => { };
    }
    set placeholder(text) {
        var _a;
        this._placeholder = text;
        if (!!text && ((_a = this.rootRef) === null || _a === void 0 ? void 0 : _a.nativeElement)) {
            this._renderer2.setAttribute(this.rootRef.nativeElement, 'placeholder', text);
        }
    }
    set errors(errors) {
        if (errors) {
            this._errors = errors;
            this._errorsKeys = Object.keys(errors);
        }
    }
    get control() {
        var _a, _b;
        return (this.formControl ||
            ((_b = (_a = this._controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    superOnInit(typeField) {
        var _a, _b, _c;
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
        if (this.required === null) {
            const value = this.control.value;
            this.control.reset();
            this.required = !!this.control.getError('required');
            this.control.setValue(value);
        }
        const iconType = (_b = (_a = this._ngConfig.types(typeField)) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()]) === null || _b === void 0 ? void 0 : _b.icon;
        const iconGlobal = (_c = this._ngConfig[typeField]) === null || _c === void 0 ? void 0 : _c.icon;
        this.icon = Object.assign({}, iconGlobal, iconType, this.icon);
    }
    superAfterViewInit() {
        if (!!this._placeholder) {
            this.placeholder = this._placeholder;
        }
    }
    handleClickIcon(prop, input, position) {
        var _a;
        prop.event.stopPropagation();
        if ((_a = prop.icon) === null || _a === void 0 ? void 0 : _a.click) {
            prop.icon.click(prop.event, input, prop.icon, position);
        }
        else {
            input.focus();
        }
    }
    handleBlur(event) {
        this.handleTouched();
        this.blur.emit(event);
    }
    handleFocus(event) {
        this.focus.emit(event);
    }
}
ControlBase.decorators = [
    { type: Component, args: [{
                template: ''
            },] }
];
ControlBase.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: NgConfigService }
];
ControlBase.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    rootRef: [{ type: ViewChild, args: ['rootRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    type: [{ type: Input }],
    prefix: [{ type: Input }],
    suffix: [{ type: Input }],
    readonly: [{ type: Input }],
    required: [{ type: Input }],
    labelFixed: [{ type: Input }],
    placeholder: [{ type: Input }],
    help: [{ type: Input }],
    color: [{ type: Input }],
    icon: [{ type: Input }],
    size: [{ type: Input }],
    theme: [{ type: Input }],
    errors: [{ type: Input }],
    blur: [{ type: Output }],
    focus: [{ type: Output }]
};

function compareObject(objectOne, ObjectTwo) {
    return JSON.stringify(objectOne) === JSON.stringify(ObjectTwo);
}
function compareOptions(options, keys, _with) {
    return options.find((item) => {
        return compareObject(getNode(item._root, keys), _with);
    });
}

const PROVIDER_VALUE_ACCESSOR$6 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgAutocompleteComponent),
    multi: true,
};
class NgAutocompleteComponent extends ControlBase {
    constructor(renderer2, ngMaskService, ngConfig, controlContainer, changeDetectorRef) {
        super(controlContainer, renderer2, ngConfig);
        this.renderer2 = renderer2;
        this.ngMaskService = ngMaskService;
        this.ngConfig = ngConfig;
        this.changeDetectorRef = changeDetectorRef;
        this.loading = false;
        this.keyLabel = '';
        this.keyValue = '';
        this.filter = false;
        this.showIsEmpty = true;
        this.secondaryControlName = '';
        this.secondaryKeyValueControl = '';
        this.positionMenu = 'auto';
        this.debounceTimeEventInput = 350;
        this._options = [];
        this._optionsRoot = [];
        this.debounceTimeInput = 0;
        this.inputDebounce = new EventEmitter();
        this.selected = new EventEmitter();
        this.selectedEmpty = new EventEmitter();
        this.writeValue = (value) => {
            if (this.rootRef && this.keyLabel.length > 0) {
                if (typeof value === 'string') {
                    this.handleSaveValue(value);
                }
                else {
                    this.rootRef.nativeElement.value = getNode(value, this.keyLabel);
                    this.handleSaveValue(value, false);
                }
            }
            else {
                setTimeout(() => {
                    this.writeValue(value);
                }, 10);
            }
        };
    }
    set options(value) {
        if (value instanceof Array && typeof value[0] === 'string') {
            this.filter = true;
        }
        this._options = value.reduce((prev, current) => {
            let result = { _label: getNode(current, this.keyLabel) };
            if (this.keyValue) {
                result._value = getNode(current, this.keyValue);
            }
            else {
                result._value = current;
            }
            result._root = current;
            return prev.concat(result);
        }, []);
        this._optionsRoot = this._options;
    }
    ngOnInit() {
        this.superOnInit('autocomplete');
    }
    ngAfterViewInit() {
        var _a, _b;
        this.superAfterViewInit();
        const typeConfig = (_a = this.ngConfig.typesInput) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()];
        const configGlobal = this.ngConfig.global.autocomplete;
        const type = this.type.toUpperCase();
        if (MASKS.typesCustom.includes(type) && this.mask === undefined) {
            this.mask = MASKS[type];
        }
        if (!(typeof this.mask === 'string') && this.mask !== undefined) {
            if (configGlobal === null || configGlobal === void 0 ? void 0 : configGlobal.mask) {
                this.mask = Object.assign({}, configGlobal === null || configGlobal === void 0 ? void 0 : configGlobal.mask, this.mask);
            }
            if (typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask) {
                this.mask = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask, this.mask);
            }
            if (((_b = this.mask) === null || _b === void 0 ? void 0 : _b.validator) === undefined) {
                this.mask = Object.assign({}, this.mask, {
                    validator: this.required,
                });
            }
        }
        if (this.mask !== undefined) {
            this._maskRef = this.ngMaskService.createMask(this.rootRef.nativeElement, this.mask, this.renderer2);
        }
        if (!INPUT_TYPE.includes(this.type)) {
            this.type = 'text';
        }
        this.rootRef.nativeElement.blur();
        this.control.markAsUntouched();
        this.changeDetectorRef.detectChanges();
    }
    handleSaveValue(value, unmask = true) {
        if (this._maskRef) {
            this.handleChange(unmask ? this._maskRef.unmaskedValue() : value);
        }
        else {
            this.handleChange(value);
        }
    }
    handleInputDebounce(value) {
        clearTimeout(this.debounceTimeInput);
        this.debounceTimeInput = setTimeout(() => {
            this.inputDebounce.emit(value);
            this.handleSearch(value);
            if (this.filter) {
                this._options = this._optionsRoot.filter((item) => contains(item._value, value));
            }
        }, this.debounceTimeEventInput);
    }
    handleSearch(value) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.service && value.length > 0) {
                this.loading = true;
                const [data] = yield handleTry(this.service[this.methodService](value));
                if (data) {
                    this.options = data;
                }
                this.loading = false;
            }
        });
    }
    handleSelect(option) {
        var _a, _b, _c, _d;
        if (option.option) {
            if (typeof ((_a = option.option.value) === null || _a === void 0 ? void 0 : _a._default) === 'string') {
                this.handleEmpty(option.option.value._default);
            }
            else {
                const optionRoot = (_b = compareOptions(this._options, this.keyValue, option.option.value)) === null || _b === void 0 ? void 0 : _b._root;
                this.rootRef.nativeElement.value = getNode(optionRoot, this.keyLabel);
                if (this.secondaryControlName) {
                    const value = getNode(optionRoot, this.secondaryKeyValueControl.split('.'));
                    (_c = this.control.root.get(this.secondaryControlName)) === null || _c === void 0 ? void 0 : _c.setValue(value);
                }
                this.selected.emit(option.option.value);
            }
        }
        else {
            this.rootRef.nativeElement.value = option._label;
            this.handleSaveValue(option._value);
            if (this.secondaryControlName) {
                (_d = this.control.root
                    .get(this.secondaryControlName)) === null || _d === void 0 ? void 0 : _d.setValue(getNode(option._root, this.secondaryKeyValueControl));
            }
            this.selected.emit(option._value);
        }
    }
    handleEmpty(valueElement = this.rootRef.nativeElement.value) {
        this.rootRef.nativeElement.value = valueElement;
        this.handleSaveValue(valueElement);
        this.selectedEmpty.emit(valueElement);
    }
    handleBlur(event, index) {
        super.handleBlur(event);
    }
    handleFocus(event) {
        super.handleFocus(event);
    }
    handleInput(event) {
        var _a;
        if ((event === null || event === void 0 ? void 0 : event.key) !== 'Enter' && !((_a = event.key) === null || _a === void 0 ? void 0 : _a.match('Arrow'))) {
            const value = event.target.value;
            this.handleInputDebounce(value);
        }
    }
}
NgAutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-autocomplete',
                template: "<label class=\"form-label\" *ngIf=\"label && theme !== 'outline'\" [for]=\"id\">\n  {{ label }}\n  <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n</label>\n\n<div\n  [class.input-group]=\"!label || (!!label && theme !== 'outline')\"\n  [class.form-floating]=\"!!label && theme === 'outline'\"\n  cdkOverlayOrigin\n  #trigger=\"cdkOverlayOrigin\"\n>\n  <ng-icon\n    *ngIf=\"!loading\"\n    [icon]=\"icon?.left\"\n    className=\"ng-bt-icon__left\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, rootRef, 'left')\"\n  ></ng-icon>\n\n  <ng-icon\n    *ngIf=\"loading\"\n    [icon]=\"icon?.loading\"\n    className=\"ng-bt-icon__left\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, rootRef, 'left')\"\n  ></ng-icon>\n\n  <input\n    [id]=\"id\"\n    #rootRef\n    [type]=\"type\"\n    autocomplete=\"off\"\n    [readonly]=\"readonly\"\n    [required]=\"required\"\n    [formControl]=\"control\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    (blur)=\"handleBlur($event)\"\n    (focus)=\"handleFocus($event)\"\n    class=\"form-control shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 0\"\n    [class.form-control-sm]=\"size === 'sm'\"\n    [class.form-control-lg]=\"size === 'lg'\"\n    [class.ng-bt-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-bt-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"control.touched && control.valid\"\n    [class.is-invalid]=\"control.touched && control.invalid\"\n  />\n\n  <label class=\"form-label\" *ngIf=\"label && theme === 'outline'\" [for]=\"id\">\n    {{ label }}\n    <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n  </label>\n\n  <ng-select-dropdown\n    [trigger]=\"trigger\"\n    [options]=\"_options\"\n    (select)=\"handleSelect($event)\"\n    (selectEmpty)=\"handleEmpty($event)\"\n  >\n    <ng-content *ngIf=\"_options.length === 0 && showIsEmpty\"></ng-content>\n  </ng-select-dropdown>\n\n  <ng-icon\n    [icon]=\"icon?.right\"\n    className=\"ng-bt-icon__right\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, rootRef, 'right')\"\n  ></ng-icon>\n</div>\n\n<div class=\"ng-bt-helper\">\n  <span\n    class=\"ng-bt-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let key of _errorsKeys\">\n    <span\n      class=\"ng-bt-helper__text ng-bt-helper__error\"\n      *ngIf=\"control.touched && control.hasError(key)\"\n    >\n      {{ _errors[key] }}\n    </span>\n  </ng-container>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$6]
            },] }
];
NgAutocompleteComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: NgMaskService },
    { type: NgConfigService },
    { type: ControlContainer },
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] }
];
NgAutocompleteComponent.propDecorators = {
    loading: [{ type: Input }],
    keyLabel: [{ type: Input }],
    keyValue: [{ type: Input }],
    filter: [{ type: Input }],
    showIsEmpty: [{ type: Input }],
    secondaryControlName: [{ type: Input }],
    secondaryKeyValueControl: [{ type: Input }],
    positionMenu: [{ type: Input }],
    service: [{ type: Input }],
    methodService: [{ type: Input }],
    debounceTimeEventInput: [{ type: Input }],
    options: [{ type: Input }],
    mask: [{ type: Input }],
    inputDebounce: [{ type: Output }],
    selected: [{ type: Output }],
    selectedEmpty: [{ type: Output }],
    handleInput: [{ type: HostListener, args: ['keyup', ['$event'],] }]
};

class NgIconComponent {
    constructor() {
        this.type = 'button';
        this.iconClick = new EventEmitter();
    }
    set icon(icon) {
        if (icon) {
            this._icon = Object.assign({}, icon);
        }
    }
    ngOnInit() { }
    handleClick(event) {
        this.iconClick.emit({ event: event, icon: this._icon });
    }
}
NgIconComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-icon',
                template: "<button\n  [type]=\"type\"\n  [disabled]=\"_icon?.disabled\"\n  *ngIf=\"_icon && !_icon?.hidden\"\n  (click)=\"handleClick($event)\"\n  [tabIndex]=\"_icon?.disabled || !_icon?.click ? -1 : 0\"\n  [class.shadow-focus]=\"!_icon?.disabled && _icon?.click\"\n  [class.ng-bt-icon__clickable]=\"!_icon?.disabled && _icon?.click\"\n  [class]=\"'ng-bt-icon input-group-text ' + _icon?.className + ' ' + className\"\n>\n  <i [class]=\"_icon?.icon\" [ngStyle]=\"{ color: _icon?.color }\"></i>\n</button>\n"
            },] }
];
NgIconComponent.ctorParameters = () => [];
NgIconComponent.propDecorators = {
    icon: [{ type: Input }],
    className: [{ type: Input }],
    type: [{ type: Input }],
    iconClick: [{ type: Output }]
};

class NgIconModule {
}
NgIconModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgIconComponent],
                exports: [NgIconComponent],
            },] }
];

class BaseModule {
}
BaseModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [ControlBase],
                exports: [ControlBase],
            },] }
];

class NgSelectDropdownComponent {
    constructor(overlay) {
        this.overlay = overlay;
        this.selectEmpty = new EventEmitter();
        this.select = new EventEmitter();
        this._indexSelect = null;
        this._isOpen = false;
        this.keyMaps = {
            Enter: () => this.handleSelect(),
            ArrowDown: () => this.handleArrowDown(),
            ArrowUp: () => this.handleArrowUp(),
        };
        this.debouceBlur = 0;
    }
    set options(options) {
        this._indexSelect = null;
        this._options = options;
    }
    ngOnInit() {
        const element = this.trigger.elementRef.nativeElement;
        element
            .querySelector('input')
            .addEventListener('focus', () => this.handleOpen());
        element
            .querySelector('input')
            .addEventListener('click', () => this.handleOpen());
        element.querySelector('input').addEventListener('keydown', (event) => {
            if (event.key === 'ArrowDown' || event.key === 'ArrowUp') {
                this.handleOpen();
            }
            if (event.key === 'Tab' || (event.key === 'Tab' && event.shiftKey)) {
                this.handleClose();
            }
        });
    }
    handleResize() {
        this.overlayUpdate();
    }
    handleKey(event) {
        if (contains(event.key, 'Arrow')) {
            if (this._indexSelect === null) {
                this._indexSelect = 0;
                return;
            }
        }
        const eventKey = this.keyMaps[event.key];
        if (eventKey) {
            eventKey();
        }
    }
    handleArrowUp() {
        if (this._options.length > 0) {
            if (this._indexSelect === 0) {
                this._indexSelect = this._options.length - 1;
                this.handleScrollInto('end');
            }
            else {
                this._indexSelect--;
                this.handleScrollInto('start');
            }
        }
    }
    handleArrowDown() {
        if (this._options.length > 0) {
            if (this._indexSelect === this._options.length - 1) {
                this._indexSelect = 0;
                this.handleScrollInto('start');
            }
            else {
                this._indexSelect++;
                this.handleScrollInto('end');
            }
        }
    }
    handleSelect(index = this._indexSelect) {
        if (this._options.length === 0) {
            this.selectEmpty.emit();
        }
        else {
            this.select.emit(this._options[index]);
        }
        this.handleClose();
    }
    handleScrollInto(block = 'nearest') {
        const button = this.listRef.nativeElement.querySelector(`button:nth-child(${this._indexSelect + 1})`);
        setTimeout(() => {
            button.scrollIntoView({ block, behavior: 'smooth' });
        });
    }
    handleOpen() {
        this.overlayUpdate();
        this._isOpen = true;
    }
    handleClose() {
        this.overlayUpdate();
        this._isOpen = false;
    }
    overlayUpdate(event) {
        this._triggerRect =
            this.trigger.elementRef.nativeElement.getBoundingClientRect();
    }
}
NgSelectDropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-select-dropdown',
                template: "<ng-template\n  cdkConnectedOverlay=\"overlayRef\"\n  (overlayKeydown)=\"handleKey($event)\"\n  [cdkConnectedOverlayOpen]=\"_isOpen\"\n  (overlayOutsideClick)=\"handleClose()\"\n  [cdkConnectedOverlayOrigin]=\"trigger\"\n  [cdkConnectedOverlayMinWidth]=\"_triggerRect?.width!\"\n>\n  <ul class=\"dropdown-menu ng-bt-dropdown show\" #listRef>\n    <button\n      (click)=\"handleSelect(0)\"\n      *ngIf=\"_options.length === 0\"\n      [class.active]=\"_indexSelect === 0\"\n      class=\"ng-bt-dropdown-item dropdown-item\"\n    >\n      <ng-content></ng-content>\n    </button>\n    <button\n      tabIndex=\"1\"\n      (click)=\"handleSelect(index)\"\n      (mouseenter)=\"_indexSelect = index\"\n      [class.active]=\"_indexSelect === index\"\n      class=\"ng-bt-dropdown-item dropdown-item\"\n      *ngFor=\"let option of _options; let index = index\"\n    >\n      {{ option._label }}\n    </button>\n  </ul>\n</ng-template>\n"
            },] }
];
NgSelectDropdownComponent.ctorParameters = () => [
    { type: Overlay }
];
NgSelectDropdownComponent.propDecorators = {
    listRef: [{ type: ViewChild, args: ['listRef',] }],
    selectEmpty: [{ type: Output }],
    select: [{ type: Output }],
    trigger: [{ type: Input }],
    options: [{ type: Input }],
    handleResize: [{ type: HostListener, args: ['window:resize', ['$event'],] }]
};

class NgAutocompleteModule {
}
NgAutocompleteModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    BaseModule,
                    NgIconModule,
                    OverlayModule,
                ],
                declarations: [NgAutocompleteComponent, NgSelectDropdownComponent],
                providers: [NgMaskService],
                exports: [NgAutocompleteComponent, NgSelectDropdownComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$5 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgInputComponent),
    multi: true,
};
class NgInputComponent extends ControlBase {
    constructor(renderer2, ngMaskCurrencyService, ngMaskPercentService, ngMaskAmountService, ngFormatDateByTypeService, ngMaskService, ngConfig, changeDetectorRef, controlContainer) {
        super(controlContainer, renderer2, ngConfig);
        this.renderer2 = renderer2;
        this.ngMaskCurrencyService = ngMaskCurrencyService;
        this.ngMaskPercentService = ngMaskPercentService;
        this.ngMaskAmountService = ngMaskAmountService;
        this.ngFormatDateByTypeService = ngFormatDateByTypeService;
        this.ngMaskService = ngMaskService;
        this.ngConfig = ngConfig;
        this.changeDetectorRef = changeDetectorRef;
        this.date = new Date();
        this.autoFillDate = false;
        this.writeValue = (value) => {
            if (this.rootRef) {
                if (this._maskRef) {
                    this._maskRef.update(value === null || value === void 0 ? void 0 : value.toString());
                }
                else {
                    if (this.ngFormatDateByTypeService.typeDate.includes(this.type)) {
                        if (!!value) {
                            this.rootRef.nativeElement.value = this.formatDate(value);
                        }
                    }
                    else {
                        this.rootRef.nativeElement.value = value === null || value === void 0 ? void 0 : value.toString();
                    }
                }
                this.handleInput(value, true);
            }
            else {
                setTimeout(() => {
                    this.writeValue(value);
                }, 10);
            }
        };
    }
    ngOnInit() {
        this.superOnInit('input');
    }
    ngAfterViewInit() {
        var _a, _b, _c, _d, _e, _f;
        this.superAfterViewInit();
        const typeConfig = (_a = this.ngConfig.typesInput) === null || _a === void 0 ? void 0 : _a[this.type.toLowerCase()];
        const configGlobal = (_b = this.ngConfig.global) === null || _b === void 0 ? void 0 : _b.input;
        if (this.type === 'currency') {
            this.currency = Object.assign({}, configGlobal === null || configGlobal === void 0 ? void 0 : configGlobal.currency, this.currency);
            if (((_c = this.currency) === null || _c === void 0 ? void 0 : _c.validator) === undefined) {
                this.currency = Object.assign({}, this.currency, {
                    validator: this.required,
                });
            }
            this.currency = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.currency, this.currency);
            this._maskRef = this.ngMaskCurrencyService.createMask(this.rootRef.nativeElement, this.currency, this.renderer2);
        }
        else if (this.type === 'percent') {
            this.percent = Object.assign({}, configGlobal === null || configGlobal === void 0 ? void 0 : configGlobal.percent, this.percent);
            if (((_d = this.percent) === null || _d === void 0 ? void 0 : _d.validator) === undefined) {
                this.percent = Object.assign({}, this.percent, {
                    validator: this.required,
                });
            }
            this.percent = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.percent, this.percent);
            this._maskRef = this.ngMaskPercentService.createMask(this.rootRef.nativeElement, this.percent, this.renderer2);
        }
        else if (this.type === 'amount') {
            this.amount = Object.assign({}, configGlobal === null || configGlobal === void 0 ? void 0 : configGlobal.amount, this.amount);
            if (((_e = this.amount) === null || _e === void 0 ? void 0 : _e.validator) === undefined) {
                this.amount = Object.assign({}, this.amount, {
                    validator: this.required,
                });
            }
            this.amount = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.amount, this.amount);
            this._maskRef = this.ngMaskAmountService.createMask(this.rootRef.nativeElement, this.amount, this.renderer2);
        }
        else {
            const type = this.type.toUpperCase();
            if (MASKS.typesCustom.includes(type) && this.mask === undefined) {
                this.mask = MASKS[type];
            }
            if (!(typeof this.mask === 'string') && this.mask !== undefined) {
                if (configGlobal === null || configGlobal === void 0 ? void 0 : configGlobal.mask) {
                    this.mask = Object.assign({}, configGlobal === null || configGlobal === void 0 ? void 0 : configGlobal.mask, this.mask);
                }
                if (typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask) {
                    this.mask = Object.assign({}, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.mask, this.mask);
                }
                if (((_f = this.mask) === null || _f === void 0 ? void 0 : _f.validator) === undefined) {
                    this.mask = Object.assign({}, this.mask, {
                        validator: this.required,
                    });
                }
            }
            if (this.mask !== undefined) {
                this._maskRef = this.ngMaskService.createMask(this.rootRef.nativeElement, this.mask, this.renderer2);
            }
        }
        if (!INPUT_TYPE.includes(this.type)) {
            this.type = 'text';
        }
        if (this.autoFillDate &&
            this.ngFormatDateByTypeService.typeDate.includes(this.type)) {
            this.rootRef.nativeElement.value = this.formatDate(this.date);
        }
        this.rootRef.nativeElement.blur();
        this.control.markAsUntouched();
        this.changeDetectorRef.detectChanges();
    }
    formatDate(value) {
        return this.ngFormatDateByTypeService.format(value.toString(), this.type);
    }
    handleInput(value, delay = false) {
        if (this._maskRef) {
            if (delay) {
                setTimeout(() => {
                    this.handleChange(this._maskRef.unmaskedValue());
                });
            }
            else {
                this.handleChange(this._maskRef.unmaskedValue());
            }
        }
        else {
            this.handleChange(value);
        }
    }
}
NgInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-input',
                template: "<label class=\"form-label\" *ngIf=\"label && theme !== 'outline'\" [for]=\"id\">\n  {{ label }}\n  <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n</label>\n\n<div\n  [class.input-group]=\"!label || (!!label && theme !== 'outline')\"\n  [class.form-floating]=\"!!label && theme === 'outline'\"\n>\n  <ng-icon\n    [icon]=\"icon?.left\"\n    className=\"ng-bt-icon__left\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, rootRef, 'left')\"\n  ></ng-icon>\n\n  <input\n    [id]=\"id\"\n    #rootRef\n    [type]=\"type\"\n    [required]=\"required\"\n    [readonly]=\"readonly\"\n    [formControl]=\"control\"\n    [attr.maxlength]=\"length\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    (blur)=\"handleBlur($event)\"\n    (focus)=\"handleFocus($event)\"\n    class=\"form-control shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 0\"\n    [class.form-control-sm]=\"size === 'sm'\"\n    [class.form-control-lg]=\"size === 'lg'\"\n    [class.ng-bt-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-bt-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"control.touched && control.valid\"\n    [class.is-invalid]=\"control.touched && control.invalid\"\n  />\n\n  <label class=\"form-label\" *ngIf=\"label && theme === 'outline'\" [for]=\"id\">\n    {{ label }}\n    <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n  </label>\n\n  <ng-icon\n    [icon]=\"icon?.right\"\n    className=\"ng-bt-icon__right\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, rootRef, 'right')\"\n  ></ng-icon>\n</div>\n\n<div class=\"ng-bt-helper\">\n  <span\n    class=\"ng-bt-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let key of _errorsKeys\">\n    <span\n      class=\"ng-bt-helper__text ng-bt-helper__error\"\n      *ngIf=\"control.touched && control.hasError(key)\"\n    >\n      {{ _errors[key] }}\n    </span>\n  </ng-container>\n\n  <span class=\"ng-bt-helper__counter text-muted\" *ngIf=\"length\">\n    {{ rootRef?.value?.length }}/{{ length }}\n  </span>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$5]
            },] }
];
NgInputComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: NgMaskCurrencyService },
    { type: NgMaskPercentService },
    { type: NgMaskAmountService },
    { type: NgFormatDateByTypeService },
    { type: NgMaskService },
    { type: NgConfigService },
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] },
    { type: ControlContainer }
];
NgInputComponent.propDecorators = {
    amount: [{ type: Input }],
    percent: [{ type: Input }],
    currency: [{ type: Input }],
    length: [{ type: Input }],
    mask: [{ type: Input }],
    date: [{ type: Input }],
    autoFillDate: [{ type: Input }],
    handleInput: [{ type: HostListener, args: ['input', ['$event.target.value'],] }]
};

class NgInputModule {
}
NgInputModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    NgConfigModule,
                    NgMasksServicesModule,
                    ReactiveFormsModule,
                    NgUtilsServiceModule,
                    NgIconModule,
                    BaseModule,
                ],
                declarations: [NgInputComponent],
                exports: [NgInputComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$4 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgSelectComponent),
    multi: true,
};
class NgSelectComponent extends SelectControlValueAccessor {
    constructor(controlContainer, renderer2, ngInputConfig, elementRef, changeDetectorRef) {
        super(renderer2, elementRef);
        this.controlContainer = controlContainer;
        this.renderer2 = renderer2;
        this.ngInputConfig = ngInputConfig;
        this.label = '';
        this.type = 'select';
        this.readonly = false;
        this.multiple = false;
        this.disabled = false;
        this.labelFixed = false;
        this.optionsFormat = 'CUSTOM';
        this.theme = 'outline';
        this.color = 'primary';
        this.required = null;
        this.keyValue = '';
        this.keyCompare = '';
        this.firstOptionValue = '';
        this.size = 'md';
        this.position = 'start';
        this._options = [];
        this.handleCompareWithBind = this.handleCompareWith.bind(this);
        this.focus = new EventEmitter();
        this.selected = new EventEmitter();
        this.handleChange = (_) => { };
        this.setDisabledState = (isDisabled) => (this.disabled = isDisabled);
        this.registerOnChange = (fn) => (this.handleChange = fn);
        this.writeValue = (value) => { };
    }
    set options(options) {
        this._options = options.map((option) => {
            let label = '';
            let value = '';
            if (option.value !== undefined && option.label !== undefined) {
                label = option.label;
                value = option.value;
                this.optionsFormat = 'NATIVE';
            }
            else {
                if (!(option === null || option === void 0 ? void 0 : option._label)) {
                    label = getNode(option, this.keyLabel);
                }
                if (!(typeof option._value === 'string')) {
                    if (this.keyValue) {
                        value = getNode(option, this.keyValue);
                    }
                    else {
                        value = option._value || option;
                    }
                }
            }
            option = {
                _label: label,
                _value: value,
                _root: option,
            };
            return option;
        });
    }
    set placeholder(text) {
        var _a;
        this._placeholder = text;
        if (!!text && ((_a = this.rootRef) === null || _a === void 0 ? void 0 : _a.nativeElement)) {
            this.renderer2.setAttribute(this.rootRef.nativeElement, 'placeholder', text);
        }
    }
    set errors(errors) {
        if (errors) {
            this._errors = errors;
            this._errorsKeys = Object.keys(errors);
        }
    }
    get control() {
        var _a, _b;
        return (this.formControl ||
            ((_b = (_a = this.controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        var _a, _b;
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
        if (this.required === null) {
            const value = this.control.value;
            this.control.reset();
            this.required = !!this.control.getError('required');
            this.control.setValue(value);
        }
        const typeConfig = (_a = this.ngInputConfig.typesSelect) === null || _a === void 0 ? void 0 : _a[this.type];
        this.icon = Object.assign({}, (_b = this.ngInputConfig.select) === null || _b === void 0 ? void 0 : _b.icon, typeConfig === null || typeConfig === void 0 ? void 0 : typeConfig.icon, this.icon);
    }
    ngAfterViewInit() {
        if (!!this._placeholder) {
            this.placeholder = this._placeholder;
        }
    }
    handleCompareWith(itemOne, itemTwo) {
        var _a, _b;
        if (this.optionsFormat === 'NATIVE') {
            return compareObject(itemOne, itemTwo);
        }
        if (!!this.keyValue) {
            itemOne = (_a = compareOptions(this._options, this.keyValue, itemOne)) === null || _a === void 0 ? void 0 : _a._root;
        }
        if (!!this.keyValue) {
            itemTwo = (_b = compareOptions(this._options, this.keyValue, itemTwo)) === null || _b === void 0 ? void 0 : _b._root;
        }
        return itemOne && itemTwo
            ? compareObject(getNode(itemOne, this.keyCompare), getNode(itemTwo, this.keyCompare))
            : itemOne === itemTwo;
    }
    handleClickIcon(prop, input, position) {
        var _a;
        prop.event.stopPropagation();
        if ((_a = prop.icon) === null || _a === void 0 ? void 0 : _a.click) {
            prop.icon.click(prop.event, input, prop.icon, position);
        }
        else {
            input.focus();
        }
    }
    handleBlur(event) {
        throw new Error('Method not implemented.');
    }
    handleFocus(event) {
        this.focus.emit(event);
    }
    handleSelect(option) {
        this.selected.emit(option.value);
    }
    handleInput(value) {
        this.handleChange(value);
    }
}
NgSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-select',
                template: "<label class=\"form-label\" *ngIf=\"label && theme !== 'outline'\" [for]=\"id\">\n  {{ label }}\n  <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n</label>\n\n<div\n  [class.input-group]=\"!label || (!!label && theme !== 'outline')\"\n  [class.form-floating]=\"!!label && theme === 'outline'\"\n>\n  <ng-icon\n    [icon]=\"icon?.left\"\n    className=\"ng-bt-icon__left\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, selectRef, 'left')\"\n  ></ng-icon>\n\n  <select\n    [id]=\"id\"\n    #selectRef\n    [required]=\"required\"\n    [formControl]=\"control\"\n    [attr.readonly]=\"readonly\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    (focus)=\"handleFocus($event)\"\n    class=\"form-select shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 0\"\n    [class.form-select-sm]=\"size === 'sm'\"\n    [class.form-select-lg]=\"size === 'lg'\"\n    [compareWith]=\"handleCompareWith.bind(this)\"\n    [class.ng-bt-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-bt-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"control.touched && control.valid\"\n    [class.is-invalid]=\"control.touched && control.invalid\"\n  >\n    <ng-container *ngIf=\"position === 'start'\">\n      <option *ngFor=\"let option of _options\" [ngValue]=\"option._value\">\n        {{ option._label }}\n      </option>\n    </ng-container>\n\n    <ng-content></ng-content>\n\n    <ng-container *ngIf=\"position === 'end'\">\n      <option *ngFor=\"let option of _options\" [ngValue]=\"option._value\">\n        {{ option._label }}\n      </option>\n    </ng-container>\n  </select>\n\n  <label class=\"form-label\" *ngIf=\"label && theme === 'outline'\" [for]=\"id\">\n    {{ label }}\n    <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n  </label>\n\n  <ng-icon\n    [icon]=\"icon?.right\"\n    className=\"ng-bt-icon__right\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, selectRef, 'right')\"\n  ></ng-icon>\n</div>\n\n<div class=\"ng-bt-helper\">\n  <span\n    class=\"ng-bt-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let key of _errorsKeys\">\n    <span\n      class=\"ng-bt-helper__text ng-bt-helper__error\"\n      *ngIf=\"control.touched && control.hasError(key)\"\n    >\n      {{ _errors[key] }}\n    </span>\n  </ng-container>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$4]
            },] }
];
NgSelectComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: NgConfigService },
    { type: ElementRef },
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] }
];
NgSelectComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    rootRef: [{ type: ViewChild, args: ['rootRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    type: [{ type: Input }],
    prefix: [{ type: Input }],
    suffix: [{ type: Input }],
    readonly: [{ type: Input }],
    multiple: [{ type: Input }],
    labelFixed: [{ type: Input }],
    optionsFormat: [{ type: Input }],
    theme: [{ type: Input }],
    help: [{ type: Input }],
    color: [{ type: Input }],
    required: [{ type: Input }],
    icon: [{ type: Input }],
    keyLabel: [{ type: Input }],
    keyValue: [{ type: Input }],
    keyCompare: [{ type: Input }],
    firstOptionLabel: [{ type: Input }],
    firstOptionValue: [{ type: Input }],
    size: [{ type: Input }],
    position: [{ type: Input }],
    options: [{ type: Input }],
    placeholder: [{ type: Input }],
    errors: [{ type: Input }],
    focus: [{ type: Output }],
    selected: [{ type: Output }]
};

class NgSelectModule {
}
NgSelectModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, NgConfigModule, NgIconModule, ReactiveFormsModule],
                declarations: [NgSelectComponent],
                exports: [NgSelectComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$3 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgTextAreaComponent),
    multi: true,
};
class NgTextAreaComponent extends ControlBase {
    constructor(changeDetectorRef, ngConfig, renderer2, controlContainer) {
        super(controlContainer, renderer2, ngConfig);
        this.changeDetectorRef = changeDetectorRef;
        this.rows = 3;
        this.cols = 3;
    }
    ngOnInit() {
        this.superOnInit('textArea');
    }
    ngAfterViewInit() {
        var _a;
        this.superAfterViewInit();
        this.rootRef.nativeElement.blur();
        (_a = this.control) === null || _a === void 0 ? void 0 : _a.markAsUntouched();
        this.changeDetectorRef.detectChanges();
    }
}
NgTextAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-text-area',
                template: "<label class=\"form-label\" *ngIf=\"label && theme !== 'outline'\" [for]=\"id\">\n  {{ label }}\n  <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n</label>\n\n<div\n  [class.input-group]=\"!label || (!!label && theme !== 'outline')\"\n  [class.form-floating]=\"!!label && theme === 'outline'\"\n>\n  <ng-icon\n    [icon]=\"icon?.left\"\n    className=\"ng-icon__left\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, rootRef, 'left')\"\n  ></ng-icon>\n\n  <textarea\n    [id]=\"id\"\n    #rootRef\n    [rows]=\"rows\"\n    [cols]=\"cols\"\n    [required]=\"required\"\n    [readonly]=\"readonly\"\n    [ngStyle]=\"{ height: 36.5 * +rows + 'px' }\"\n    [formControl]=\"control\"\n    [attr.maxlength]=\"length\"\n    [class.disabled]=\"disabled\"\n    [class.readonly]=\"readonly\"\n    (blur)=\"handleBlur($event)\"\n    (focus)=\"handleFocus($event)\"\n    class=\"form-control shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 0\"\n    [class.form-control-sm]=\"size === 'sm'\"\n    [class.form-control-lg]=\"size === 'lg'\"\n    [class.ng-icon__left]=\"icon?.left && !icon?.left?.hidden\"\n    [class.ng-icon__right]=\"icon?.right && !icon?.right?.hidden\"\n    [class.is-valid]=\"control.touched && control.valid\"\n    [class.is-invalid]=\"control.touched && control.invalid\"\n  >\n  <ng-content></ng-content>\n  </textarea>\n\n  <label class=\"form-label\" *ngIf=\"label && theme === 'outline'\" [for]=\"id\">\n    {{ label }}\n    <span class=\"ng-bt-required-symbol\" *ngIf=\"required\">*</span>\n  </label>\n\n  <ng-icon\n    [icon]=\"icon?.right\"\n    className=\"ng-bt-icon__right\"\n    [class.is-valid]=\"control.valid && control.touched\"\n    [class.is-invalid]=\"control.invalid && control.touched\"\n    (iconClick)=\"handleClickIcon($event, rootRef, 'right')\"\n  ></ng-icon>\n</div>\n\n<div class=\"ng-bt-helper\">\n  <span\n    class=\"ng-bt-helper__text text-muted\"\n    *ngIf=\"help && !(control.touched && control.invalid)\"\n  >\n    {{ help }}\n  </span>\n\n  <ng-container *ngFor=\"let key of _errorsKeys\">\n    <span\n      class=\"ng-bt-helper__text ng-bt-helper__error\"\n      *ngIf=\"control.touched && control.hasError(key)\"\n    >\n      {{ _errors[key] }}\n    </span>\n  </ng-container>\n\n  <span class=\"ng-bt-helper__counter text-muted\" *ngIf=\"length\">\n    {{ rootRef?.value?.length }}/{{ length }}\n  </span>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$3]
            },] }
];
NgTextAreaComponent.ctorParameters = () => [
    { type: ChangeDetectorRef, decorators: [{ type: SkipSelf }] },
    { type: NgConfigService },
    { type: Renderer2 },
    { type: ControlContainer }
];
NgTextAreaComponent.propDecorators = {
    rows: [{ type: Input }],
    cols: [{ type: Input }],
    length: [{ type: Input }]
};

class NgTextAreaModule {
}
NgTextAreaModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, BaseModule, ReactiveFormsModule, NgIconModule],
                declarations: [NgTextAreaComponent],
                exports: [NgTextAreaComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$2 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgCheckboxComponent),
    multi: true,
};
class NgCheckboxComponent extends CheckboxControlValueAccessor {
    constructor(controlContainer, renderer2, elementRef) {
        super(renderer2, elementRef);
        this.controlContainer = controlContainer;
        this.renderer2 = renderer2;
        this.elementRef = elementRef;
        this.indeterminate = false;
        this.type = 'checkbox';
        this.color = 'primary';
        this.required = false;
        this.labelPosition = 'after';
    }
    get control() {
        var _a, _b;
        return (this.formControl ||
            ((_b = (_a = this.controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
    }
    ngAfterViewInit() { }
}
NgCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-checkbox',
                template: "<div class=\"form-check form-check-inline\">\n  <input\n    [id]=\"id\"\n    #checkboxRef\n    type=\"checkbox\"\n    [required]=\"required\"\n    [formControl]=\"control\"\n    class=\"form-check-input shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 0\"\n  />\n  <label [for]=\"id\" class=\"form-check-label\">\n    <ng-content></ng-content>\n  </label>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$2]
            },] }
];
NgCheckboxComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: ElementRef }
];
NgCheckboxComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    checkboxRef: [{ type: ViewChild, args: ['checkboxRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    readonly: [{ type: Input }],
    indeterminate: [{ type: Input }],
    type: [{ type: Input }],
    color: [{ type: Input }],
    required: [{ type: Input }],
    labelPosition: [{ type: Input }]
};

class NgCheckboxModule {
}
NgCheckboxModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ReactiveFormsModule],
                declarations: [NgCheckboxComponent],
                exports: [NgCheckboxComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR$1 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgSwitchComponent),
    multi: true,
};
class NgSwitchComponent extends CheckboxControlValueAccessor {
    constructor(controlContainer, renderer2, elementRef) {
        super(renderer2, elementRef);
        this.controlContainer = controlContainer;
        this.renderer2 = renderer2;
        this.elementRef = elementRef;
        this.type = 'checkbox';
        this.color = 'primary';
        this.required = false;
        this.labelPosition = 'after';
    }
    get control() {
        var _a, _b;
        return (this.formControl ||
            ((_b = (_a = this.controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    ngOnInit() {
        if (this.id === undefined) {
            this.id = this.formControlName;
        }
    }
}
NgSwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-switch',
                template: "<div class=\"form-check form-switch form-check-inline\">\n  <input\n    [id]=\"id\"\n    #checkboxRef\n    type=\"checkbox\"\n    [required]=\"required\"\n    [formControl]=\"control\"\n    class=\"form-check-input shadow-focus\"\n    [tabIndex]=\"control.disabled ? -1 : 0\"\n  />\n  <label [for]=\"id\" class=\"form-check-label\">\n    <ng-content></ng-content>\n  </label>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR$1]
            },] }
];
NgSwitchComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: Renderer2 },
    { type: ElementRef }
];
NgSwitchComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    checkboxRef: [{ type: ViewChild, args: ['checkboxRef',] }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    id: [{ type: Input }],
    readonly: [{ type: Input }],
    type: [{ type: Input }],
    color: [{ type: Input }],
    required: [{ type: Input }],
    labelPosition: [{ type: Input }]
};

class NgSwitchModule {
}
NgSwitchModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ReactiveFormsModule],
                declarations: [NgSwitchComponent],
                exports: [NgSwitchComponent],
            },] }
];

const PROVIDER_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgUploadComponent),
    multi: true,
};
class NgUploadComponent {
    constructor(_controlContainer, ngConfigService) {
        this._controlContainer = _controlContainer;
        this.ngConfigService = ngConfigService;
        this.icon = '';
        this.multiple = false;
        this.accept = '';
        this.disabled = false;
        this.stateDragDrop = 'DRAGLEAVE';
        this.handleChange = (_) => { };
        this.handleTouched = () => { };
        this.registerOnTouched = (fn) => (this.handleTouched = fn);
        this.setDisabledState = (isDisabled) => (this.disabled = isDisabled);
        this.registerOnChange = (fn) => (this.handleChange = fn);
        this.writeValue = (value) => { };
    }
    set errors(errors) {
        if (errors) {
            this._errors = errors;
            this._errorsKeys = Object.keys(errors);
        }
    }
    get control() {
        var _a, _b;
        return (this.formControl ||
            ((_b = (_a = this._controlContainer) === null || _a === void 0 ? void 0 : _a.control) === null || _b === void 0 ? void 0 : _b.get(this.formControlName)));
    }
    //Dragover listener
    handleDragOver(event) {
        this.stateDragDrop = 'DRAGOVER';
    }
    ngOnInit() {
        var _a, _b;
        if (!this.label) {
            this.label = (_a = this.ngConfigService.upload) === null || _a === void 0 ? void 0 : _a.label;
        }
        if (!this.icon) {
            this.icon = (_b = this.ngConfigService.upload) === null || _b === void 0 ? void 0 : _b.icon;
        }
    }
    handleDrop() {
        this.stateDragDrop = 'DROP';
    }
    handleOpenUpload() {
        this.rootRef.nativeElement.click();
    }
}
NgUploadComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-upload',
                template: "<div\n  class=\"form-upload\"\n  [class.form-upload__is-valid]=\"control.touched && control.valid\"\n  [class.form-upload__is-invalid]=\"control.touched && control.invalid\"\n  [class.form-upload__is-drag-over]=\"stateDragDrop === 'DRAGOVER'\"\n>\n  <input\n    #rootRef\n    type=\"file\"\n    [tabIndex]=\"-1\"\n    [accept]=\"accept\"\n    [multiple]=\"multiple\"\n    (drop)=\"handleDrop()\"\n    [formControl]=\"control\"\n    (change)=\"handleTouched()\"\n    class=\"form-upload__control\"\n    (dragleave)=\"stateDragDrop = 'DRAGLEAVE'\"\n    [class.disabled]=\"stateDragDrop !== 'DRAGOVER'\"\n  />\n\n  <div class=\"form-upload__content\">\n    <i [class]=\"icon + ' form-upload__content___icon'\"></i>\n    <button\n      tabindex=\"0\"\n      class=\"form-upload__content___button btn shadow-focus\"\n      (click)=\"handleOpenUpload()\"\n    >\n      browser\n    </button>\n    <p class=\"form-upload__content___description\">{{ label }}</p>\n\n    <div class=\"form-upload__content___helper ng-bt-helper\">\n      <ng-container *ngFor=\"let key of _errorsKeys\">\n        <span\n          class=\"ng-bt-helper__text ng-bt-helper__error\"\n          *ngIf=\"control.touched && control.hasError(key)\"\n        >\n          {{ _errors[key] }}\n        </span>\n      </ng-container>\n    </div>\n  </div>\n</div>\n",
                providers: [PROVIDER_VALUE_ACCESSOR],
                styles: [".form-upload{width:100%;min-height:250px;padding:20px;display:flex;position:relative;margin-bottom:10px;border-radius:4px;align-items:center;flex-direction:column;justify-content:center;background-color:var(--color-input-background);border:2px dashed #333333b3}.form-upload .form-upload__control{top:0;left:0;opacity:0;width:100%;height:100%;position:absolute}.form-upload .form-upload__control.form-upload__control___disabled,.form-upload:before{touch-action:none;pointer-events:none}.form-upload:before{content:\"\";top:0;left:0;opacity:0;width:100%;height:100%;display:flex;transition:.25s;position:absolute;background-color:var(--color-input-background)}.form-upload.form-upload__is-drag-over{border-color:var(--color-primary)}.form-upload.form-upload__is-drag-over:before{opacity:.1;background-color:var(--color-primary)}.form-upload.form-upload__is-invalid{border-color:var(--color-danger)}.form-upload.form-upload__is-invalid:before{opacity:.1;background-color:var(--color-danger)}.form-upload.form-upload__is-valid{border-color:var(--color-success)}.form-upload.form-upload__is-valid:before{opacity:.1;background-color:var(--color-success)}.form-upload .form-upload__content{display:flex;align-items:center;flex-direction:column;justify-content:center}.form-upload .form-upload__content .form-upload__content___icon{font-size:75px;margin-bottom:20px;opacity:.5}.form-upload .form-upload__content .form-upload__content___button{margin-bottom:5px;color:var(--color-text-secondary);background-color:var(--color-primary)!important}.form-upload .form-upload__content .form-upload__content___description{margin:0;font-size:16px;font-weight:500;opacity:.9}.form-upload .form-upload__content .form-upload__content___helper,.form-upload .form-upload__content .form-upload__content___helper .ng-bt-helper__text{display:flex;align-items:center;justify-content:center}"]
            },] }
];
NgUploadComponent.ctorParameters = () => [
    { type: ControlContainer },
    { type: NgConfigService }
];
NgUploadComponent.propDecorators = {
    formControlDirective: [{ type: ViewChild, args: [FormControlDirective, { static: true },] }],
    rootRef: [{ type: ViewChild, args: ['rootRef',] }],
    icon: [{ type: Input }],
    multiple: [{ type: Input }],
    accept: [{ type: Input }],
    formControl: [{ type: Input }],
    formControlName: [{ type: Input }],
    label: [{ type: Input }],
    errors: [{ type: Input }],
    handleDragOver: [{ type: HostListener, args: ['dragover', ['$event'],] }]
};

class NgUploadListComponent {
    constructor() {
        this.files = [
            {
                name: 'Douglas.png',
                size: 1024,
                src: 'https://avatars.githubusercontent.com/u/61251163?v=4',
                type: 'image/png',
            },
        ];
    }
    set ngUploadRef(value) {
        if (this.$valueChanges) {
            this.$valueChanges.unsubscribe();
        }
        this._ngUploadRef = value;
        this.$valueChanges = this._ngUploadRef.control.valueChanges.subscribe((files) => {
            Array.from(files).forEach((file) => __awaiter(this, void 0, void 0, function* () {
                this.files.push({
                    name: file.name,
                    type: file.type,
                    size: file.size,
                    src: yield this.handleBase64(file),
                });
            }));
        });
    }
    handleBase64(result) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                const fileReader = new FileReader();
                fileReader.onload = () => resolve(fileReader.result);
                fileReader.onerror = (error) => reject(error);
                fileReader.readAsDataURL(result);
            });
        });
    }
    ngOnInit() { }
}
NgUploadListComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-upload-list',
                template: "<ul class=\"list-files\">\n  <li class=\"list-files-item\" *ngFor=\"let file of files\">\n    <div class=\"list-file-item__image___container\">\n      <img class=\"list-files-item__image\" [src]=\"file.src\" [alt]=\"file.name\" />\n    </div>\n    <div class=\"list-files-item__info\">\n      <h4 class=\"list-files-item__info___name\" [title]=\"file.name\">\n        {{ file.name }}\n      </h4>\n      <p class=\"list-files-item__info___description\">\n        {{ file.type }} - {{ file.size / 1024 }} KB\n      </p>\n    </div>\n    <button class=\"btn list-files-item__button\">\n      <i class=\"fas fa-times\"></i>\n    </button>\n  </li>\n</ul>\n",
                styles: [".list-files{padding:0;list-style:none}.list-files .list-files-item{height:70px;display:flex;border-radius:5px;margin-bottom:10px;align-items:center;justify-content:center;border:1px solid #0000001f;background-color:var(--color-input-background)}.list-files .list-files-item .list-file-item__image___container{height:4.375rem;width:100%;max-width:105px;overflow:hidden;border-right:1px solid #0000001f;border-top-left-radius:5px;border-bottom-left-radius:5px}.list-files .list-files-item .list-file-item__image___container .list-files-item__image{width:100%;height:100%;object-fit:cover;object-position:center}@media (max-width:960px){.list-files .list-files-item .list-file-item__image___container{display:none}}.list-files .list-files-item .list-files-item__info{width:100%;margin-left:15px;overflow:hidden}.list-files .list-files-item .list-files-item__info .list-files-item__info___name{margin:0;font-size:18px;white-space:nowrap;text-overflow:ellipsis}.list-files .list-files-item .list-files-item__info .list-files-item__info___description{margin:0;opacity:.7;font-size:14px}.list-files .list-files-item .list-files-item__button{margin-right:10px}"]
            },] }
];
NgUploadListComponent.ctorParameters = () => [];
NgUploadListComponent.propDecorators = {
    ngUploadRef: [{ type: Input }]
};

class NgUploadModule {
}
NgUploadModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ReactiveFormsModule, NgFileDirectivesModule],
                declarations: [NgUploadComponent, NgUploadListComponent],
                exports: [NgUploadComponent, NgUploadListComponent],
            },] }
];

/*
 * Public API Surface of ng-fields
 */

/**
 * Generated bundle index. Do not edit.
 */

export { FOR_ROOT_OPTIONS_TOKEN, NgAutocompleteComponent, NgAutocompleteModule, NgCheckboxComponent, NgCheckboxModule, NgFormatDateByTypeService, NgInputComponent, NgInputModule, NgInputsBootstrap, NgSelectComponent, NgSelectModule, NgSwitchComponent, NgSwitchModule, NgTextAreaComponent, NgTextAreaModule, NgUploadComponent, NgUploadListComponent, NgUploadModule, NgUtilsServiceModule, provideMyServiceOptions, NgConfigModule as ɵa, NgConfigService as ɵb, BaseModule as ɵc, ControlBase as ɵd, NgIconModule as ɵe, NgIconComponent as ɵf, NgSelectDropdownComponent as ɵg };
//# sourceMappingURL=douglas-serena-ng-inputs-bootstrap.js.map
